namespace FSpot {
	public interface IPhotoCollection : IBrowsableCollection {
	}
}
